@@ -1,16 +1,14 @@
-use crate::{
-    executor::{DefaultExecutor, Executor},
-    reactor::ReactorBuilder,
-    types::{AMQPValue, FieldTable, LongString},
-};
+use crate::types::{AMQPValue, FieldTable, LongString};
+use executor_trait::FullExecutor;
+use reactor_trait::Reactor;
 use std::sync::Arc;
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub struct ConnectionProperties {
     pub locale: String,
     pub client_properties: FieldTable,
-    pub executor: Option<Arc<dyn Executor>>,
-    pub reactor_builder: Option<Arc<dyn ReactorBuilder>>,
+    pub executor: Option<Arc<dyn FullExecutor + Send + Sync>>,
+    pub reactor: Option<Arc<dyn Reactor + Send + Sync>>,
 }
 
 impl Default for ConnectionProperties {
@@ -19,12 +17,13 @@ impl Default for ConnectionProperties {
             locale: "en_US".into(),
             client_properties: FieldTable::default(),
             executor: None,
-            reactor_builder: None,
+            reactor: None,
         }
     }
 }
 
 impl ConnectionProperties {
+    #[must_use]
     pub fn with_connection_name(mut self, connection_name: LongString) -> Self {
         self.client_properties.insert(
             "connection_name".into(),
@@ -33,17 +32,15 @@ impl ConnectionProperties {
         self
     }
 
-    pub fn with_executor<E: Executor + 'static>(mut self, executor: E) -> Self {
+    #[must_use]
+    pub fn with_executor<E: FullExecutor + Send + Sync + 'static>(mut self, executor: E) -> Self {
         self.executor = Some(Arc::new(executor));
         self
     }
 
-    pub fn with_default_executor(self, max_threads: usize) -> Self {
-        self.with_executor(DefaultExecutor::new(max_threads))
-    }
-
-    pub fn with_reactor<R: ReactorBuilder + 'static>(mut self, reactor_builder: R) -> Self {
-        self.reactor_builder = Some(Arc::new(reactor_builder));
+    #[must_use]
+    pub fn with_reactor<R: Reactor + Send + Sync + 'static>(mut self, reactor: R) -> Self {
+        self.reactor = Some(Arc::new(reactor));
         self
     }
 }
