@@ -1,9 +1,8 @@
-use crate::{channel::Reply, Error, Promise, PromiseResolver};
+use crate::{channel::Reply, types::ChannelId, Error, Promise, PromiseResolver};
 use amq_protocol::{
     frame::AMQPFrame,
     protocol::{basic::AMQPMethod, AMQPClass},
 };
-use log::{log_enabled, trace, Level::Trace};
 use parking_lot::Mutex;
 use pinky_swear::Cancellable;
 use std::{
@@ -11,6 +10,7 @@ use std::{
     fmt,
     sync::Arc,
 };
+use tracing::{level_enabled, trace, Level};
 
 pub(crate) struct ExpectedReply(
     pub(crate) Reply,
@@ -31,7 +31,7 @@ pub(crate) struct Frames {
 impl Frames {
     pub(crate) fn push(
         &self,
-        channel_id: u16,
+        channel_id: ChannelId,
         frame: AMQPFrame,
         resolver: PromiseResolver<()>,
         expected_reply: Option<ExpectedReply>,
@@ -55,7 +55,7 @@ impl Frames {
 
     pub(crate) fn find_expected_reply<P: FnMut(&ExpectedReply) -> bool>(
         &self,
-        channel_id: u16,
+        channel_id: ChannelId,
         finder: P,
     ) -> Option<Reply> {
         self.inner
@@ -89,11 +89,12 @@ impl Frames {
         self.inner.lock().drop_pending(error);
     }
 
-    pub(crate) fn clear_expected_replies(&self, channel_id: u16, error: Error) {
+    pub(crate) fn clear_expected_replies(&self, channel_id: ChannelId, error: Error) {
         self.inner.lock().clear_expected_replies(channel_id, error);
     }
 }
 
+#[derive(Default)]
 struct Inner {
     /* Header frames must follow basic.publish frames directly, otherwise RabbitMQ-server send us an UNEXPECTED_FRAME */
     /* After sending the Header frame, we need to send the associated Body frames before anything else for the same reason */
@@ -101,19 +102,7 @@ struct Inner {
     retry_frames: VecDeque<(AMQPFrame, Option<PromiseResolver<()>>)>,
     frames: VecDeque<(AMQPFrame, Option<PromiseResolver<()>>)>,
     low_prio_frames: VecDeque<(AMQPFrame, Option<PromiseResolver<()>>)>,
-    expected_replies: HashMap<u16, VecDeque<ExpectedReply>>,
-}
-
-impl Default for Inner {
-    fn default() -> Self {
-        Self {
-            publish_frames: VecDeque::default(),
-            retry_frames: VecDeque::default(),
-            frames: VecDeque::default(),
-            low_prio_frames: VecDeque::default(),
-            expected_replies: HashMap::default(),
-        }
-    }
+    expected_replies: HashMap<ChannelId, VecDeque<ExpectedReply>>,
 }
 
 impl fmt::Debug for Frames {
@@ -129,7 +118,7 @@ impl fmt::Debug for Frames {
 impl Inner {
     fn push(
         &mut self,
-        channel_id: u16,
+        channel_id: ChannelId,
         frame: AMQPFrame,
         resolver: PromiseResolver<()>,
         expected_reply: Option<ExpectedReply>,
@@ -137,9 +126,9 @@ impl Inner {
         self.frames.push_back((frame, Some(resolver)));
         if let Some(reply) = expected_reply {
             trace!(
-                "channel {} state is now waiting for {:?}",
-                channel_id,
-                reply
+                channel=%channel_id,
+                expected_reply=?reply,
+                "state is now waiting"
             );
             self.expected_replies
                 .entry(channel_id)
@@ -152,7 +141,7 @@ impl Inner {
         let (promise, resolver) = Promise::new();
         let last_frame = frames.pop();
 
-        if log_enabled!(Trace) {
+        if level_enabled!(Level::TRACE) {
             promise.set_marker("Frames".into());
         }
 
@@ -164,7 +153,6 @@ impl Inner {
         } else {
             resolver.swear(Ok(()));
         }
-
         promise
     }
 
@@ -257,7 +245,7 @@ impl Inner {
         None
     }
 
-    fn clear_expected_replies(&mut self, channel_id: u16, error: Error) {
+    fn clear_expected_replies(&mut self, channel_id: ChannelId, error: Error) {
         if let Some(replies) = self.expected_replies.remove(&channel_id) {
             Self::cancel_expected_replies(replies, error);
         }
