@@ -160,10 +160,7 @@ impl IoLoop {
                     let writable_waker = self.writable_waker();
                     let mut writable_context = Context::from_waker(&writable_waker);
                     while self.should_continue() {
-                        if let Err(err) = self.run(
-                            &mut readable_context,
-                            &mut writable_context,
-                        ) {
+                        if let Err(err) = self.run(&mut readable_context, &mut writable_context) {
                             self.critical_error(err)?;
                         }
                     }
